@@ -8,6 +8,7 @@ import time
 from datetime import date, datetime
 from typing import Union
 
+import aiohttp
 import requests
 
 from tqsdk.channel import TqChan
@@ -36,7 +37,7 @@ class TqBacktest(object):
           始终为 nan, volume 始终为0
 
         * 如果即没有订阅 tick, 也没有订阅k线或 订阅的k线周期大于分钟线, 则 TqBacktest 会 **自动订阅分钟线** 来生成 quote
-        
+
     **注意** ：如果未订阅 quote，模拟交易在下单时会自动为此合约订阅 quote ，根据回测时 quote 的更新规则，如果此合约没有订阅K线或K线周期大于分钟线 **则会自动订阅一个分钟线** 。
 
     模拟交易要求报单价格大于等于对手盘价格才会成交, 例如下买单, 要求价格大于等于卖一价才会成交, 如果不能立即成交则会等到下次行情更新再重新判断。
@@ -60,13 +61,15 @@ class TqBacktest(object):
         if isinstance(start_dt, datetime):
             self._start_dt = int(start_dt.timestamp() * 1e9)
         elif isinstance(start_dt, date):
-            self._start_dt = _get_trading_day_start_time(int(datetime(start_dt.year, start_dt.month, start_dt.day).timestamp()) * 1000000000)
+            self._start_dt = _get_trading_day_start_time(
+                int(datetime(start_dt.year, start_dt.month, start_dt.day).timestamp()) * 1000000000)
         else:
             raise Exception("回测起始时间(start_dt)类型 %s 错误, 请检查 start_dt 数据类型是否填写正确" % (type(start_dt)))
         if isinstance(end_dt, datetime):
             self._end_dt = int(end_dt.timestamp() * 1e9)
         elif isinstance(end_dt, date):
-            self._end_dt = _get_trading_day_end_time(int(datetime(end_dt.year, end_dt.month, end_dt.day).timestamp()) * 1000000000)
+            self._end_dt = _get_trading_day_end_time(
+                int(datetime(end_dt.year, end_dt.month, end_dt.day).timestamp()) * 1000000000)
         else:
             raise Exception("回测结束时间(end_dt)类型 %s 错误, 请检查 end_dt 数据类型是否填写正确" % (type(end_dt)))
         self._current_dt = self._start_dt
@@ -158,7 +161,8 @@ class TqBacktest(object):
                     "pre_settlement": None,
                     "pre_close": None,
                     "ins_class": quote.get("ins_class", ""),
-                    'instrument_id': quote.get("instrument_id", ""),
+                    "instrument_id": quote.get("instrument_id", ""),
+                    "exchange_id": quote.get("exchange_id", ""),
                     "margin": quote.get("margin"),  # 用于内部实现模拟交易, 不作为api对外可用数据（即 Quote 类中无此字段）
                     "commission": quote.get("commission"),  # 用于内部实现模拟交易, 不作为api对外可用数据（即 Quote 类中无此字段）
                     "price_tick": quote["price_tick"],
@@ -250,7 +254,7 @@ class TqBacktest(object):
                 }
                 self._diffs = []
                 self._pending_peek = False
-                self._logger.debug("backtest message send: %s", rtn_data)
+                self._logger.debug("TqBacktest message send: %s", rtn_data)
                 await self._sim_recv_chan.send(rtn_data)
 
     async def _ensure_serial(self, ins, dur):
@@ -370,7 +374,8 @@ class TqBacktest(object):
                                 "datetime"] if dur < 86400000000000 else _get_trading_day_start_time(item["datetime"])
                             if timestamp > self._end_dt:  # 超过结束时间
                                 return
-                            yield timestamp, diff, None  # K线刚生成时的数据都为开盘价
+                            yield timestamp, diff, self._get_quotes_from_kline_open(self._data["quotes"][ins], timestamp,
+                                                                               item)  # K线刚生成时的数据都为开盘价
                             diff = {
                                 "klines": {
                                     ins: {
@@ -401,6 +406,25 @@ class TqBacktest(object):
         quote["datetime"] = datetime.fromtimestamp(tick["datetime"] / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f")
         return [quote]
 
+    @staticmethod
+    def _get_quotes_from_kline_open(info, timestamp, kline):
+        return [
+            {  # K线刚生成时的数据都为开盘价
+                "datetime": datetime.fromtimestamp(timestamp / 1e9).strftime("%Y-%m-%d %H:%M:%S.%f"),
+                "ask_price1": kline["open"] + info["price_tick"],
+                "ask_volume1": 1,
+                "bid_price1": kline["open"] - info["price_tick"],
+                "bid_volume1": 1,
+                "last_price": kline["open"],
+                "highest": float("nan"),
+                "lowest": float("nan"),
+                "average": float("nan"),
+                "volume": 0,
+                "amount": float("nan"),
+                "open_interest": kline["open_oi"],
+            },
+        ]
+
     @staticmethod
     def _get_quotes_from_kline(info, timestamp, kline):
         return [
@@ -431,6 +455,7 @@ class TqBacktest(object):
 
 class TqReplay(object):
     """天勤复盘类"""
+
     def __init__(self, replay_dt: date):
         """
         除了传统的回测模式以外，TqSdk 提供独具特色的复盘模式，它与回测模式有以下区别
@@ -459,6 +484,8 @@ class TqReplay(object):
         if self._replay_dt.weekday() >= 5:
             # 0~6, 检查周末[5,6] 提前抛错退出
             raise Exception("无法创建复盘服务器，请检查复盘日期后重试。")
+        self._default_speed = 1
+        self._api = None
 
     def _create_server(self, api):
         self._api = api
@@ -471,38 +498,24 @@ class TqReplay(object):
         self._md_url = "ws://%s:%d/t/rmd/front/mobile" % (session["ip"], session["gateway_web_port"])
 
         self._server_status = None
-        timeout = time.time() + 30  # 最多等待 30 s
-        # 同步等待复盘服务状态 initializing / running
-        while self._server_status is None:
-            time.sleep(1)
-            response = self._get_server_status()
-            if response and response["status"]:
-                self._server_status = response["status"]
-            if timeout < time.time():
-                break
-
-        try_times = 30  # 最多尝试 30 次
-        # 同步等待复盘服务状态 running
-        while self._server_status == "initializing" and try_times > 0:
-            time.sleep(1)
-            response = self._get_server_status()
-            try_times -= 1
-            if response and response["status"]:
-                self._server_status = response["status"]
-
+        self._server_status = self._wait_server_status("running", 60)
         if self._server_status == "running":
-            self._set_server_session({"aid": "ratio", "speed": 1})
             return self._ins_url, self._md_url
         else:
             raise Exception("无法创建复盘服务器，请检查复盘日期后重试。")
 
     async def _run(self):
         try:
+            self._send_chan = TqChan(self._api)
+            self._send_chan.send_nowait({"aid": "ratio", "speed": self._default_speed})
+            _senddata_task = self._api.create_task(self._senddata_handler())
             while True:
-                self._set_server_session({"aid": "heartbeat"})
+                await self._send_chan.send({"aid": "heartbeat"})
                 await asyncio.sleep(30)
         finally:
-            self._set_server_session({"aid": "terminate"})
+            await self._send_chan.close()
+            _senddata_task.cancel()
+            await asyncio.gather(_senddata_task, return_exceptions=True)
 
     def _prepare_session(self):
         create_session_url = "http://replay.api.shinnytech.com/t/rmd/replay/create_session"
@@ -515,22 +528,63 @@ class TqReplay(object):
         else:
             raise Exception("创建复盘服务器失败，请检查复盘日期后重试。")
 
+    def _wait_server_status(self, target_status, timeout):
+        """等服务器状态为 target_status，超时时间 timeout 秒"""
+        deadline = time.time() + timeout
+        server_status = self._get_server_status()
+        while deadline > time.time():
+            if target_status == server_status:
+                break
+            else:
+                time.sleep(1)
+                server_status = self._get_server_status()
+        return server_status
+
     def _get_server_status(self):
         try:
             response = requests.get(self._session_url,
                                     headers=self._api._base_headers,
                                     timeout=5)
             if response.status_code == 200:
-                return json.loads(response.content)
+                return json.loads(response.content)["status"]
             else:
                 raise Exception("无法创建复盘服务器，请检查复盘日期后重试。")
         except requests.exceptions.ConnectionError as e:
             # 刚开始 _session_url 还不能访问的时候～
             return None
 
-    def _set_server_session(self, data=None):
-        if data is not None:
-            requests.post(self._session_url,
-                          headers=self._api._base_headers,
-                          data=json.dumps(data),
-                          timeout=30)
+    async def _senddata_handler(self):
+        try:
+            session = aiohttp.ClientSession(headers=self._api._base_headers)
+            async for data in self._send_chan:
+                await session.post(self._session_url, data=json.dumps(data))
+        finally:
+            await session.post(self._session_url, data=json.dumps({"aid": "terminate"}))
+            await session.close()
+
+    def set_replay_speed(self, speed: float = 10.0) -> None:
+        """
+        调整复盘服务器行情推进速度
+
+        Args:
+            speed (float): 复盘服务器行情推进速度, 默认为 10.0
+
+        Example::
+
+            from datetime import date
+            from tqsdk import TqApi, TqReplay
+            replay = TqReplay(date(2019, 9, 10))
+            api = TqApi(backtest=replay)
+            replay.set_replay_speed(3.0)
+            quote = api.get_quote("SHFE.cu1912")
+            while True:
+                api.wait_update()
+                if api.is_changing(quote):
+                    print("最新价", quote.datetime, quote.last_price)
+
+        """
+        if self._api:
+            self._send_chan.send_nowait({"aid": "ratio", "speed": speed})
+        else:
+            # _api 未初始化，只记录用户设定的速度，在复盘服务器启动完成后，发动请求
+            self._default_speed = speed
