@@ -107,6 +107,8 @@ class Quote(Entity):
         self.ins_class = ""
         #: 交易所内的合约代码
         self.instrument_id = ""
+        #: 交易所代码
+        self.exchange_id = ""
         #: 合约是否已下市
         self.expired = False
         #: 交易时间段
@@ -121,6 +123,8 @@ class Quote(Entity):
         self.option_class = ""
         #: 品种代码
         self.product_id = ""
+        #: ETF实时单位基金净值
+        self.iopv = float("nan")
 
     def _instance_entity(self, path):
         super(Quote, self)._instance_entity(path)
@@ -141,6 +145,9 @@ class TradingTime(Entity):
         #: 夜盘（注意：本字段中过了 24：00 的时间则在其基础往上加，如凌晨1点为 '25:00:00' ）
         self.night = []
 
+    def __repr__(self):
+        return f"{{day: {self.day}, night: {self.night}}}"
+
 
 class Kline(Entity):
     """ Kline 是一个K线对象 """
